"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const type_1 = require("./type");
/**
 * Kind of primary type
 *
 * @export
 * @enum {number}
 */
var PrimaryTypeKind;
(function (PrimaryTypeKind) {
    PrimaryTypeKind[PrimaryTypeKind["ImplicitAny"] = 0] = "ImplicitAny";
    PrimaryTypeKind[PrimaryTypeKind["PredefinedType"] = 1] = "PredefinedType";
    PrimaryTypeKind[PrimaryTypeKind["TypeReference"] = 2] = "TypeReference";
    PrimaryTypeKind[PrimaryTypeKind["ObjectType"] = 3] = "ObjectType";
    PrimaryTypeKind[PrimaryTypeKind["ArrayType"] = 4] = "ArrayType";
    PrimaryTypeKind[PrimaryTypeKind["TupleType"] = 5] = "TupleType";
    PrimaryTypeKind[PrimaryTypeKind["TypeQuery"] = 6] = "TypeQuery";
    PrimaryTypeKind[PrimaryTypeKind["ThisType"] = 7] = "ThisType";
})(PrimaryTypeKind = exports.PrimaryTypeKind || (exports.PrimaryTypeKind = {}));
/**
 * Primary type specification
 *
 * @export
 * @class PrimaryType
 * @extends {Type}
 */
class PrimaryType extends type_1.Type {
    /**
     * Kind of primary type
     *
     * @type {PrimaryTypeKind}
     * @memberOf PrimaryType
     */
    get kind() {
        return this._kind;
    }
    set kind(value) {
        this._kind = value;
    }
    /**
     * Namespace of the type reference
     *
     * @type {string}
     * @memberOf PrimaryType
     */
    get namespace() {
        return this._namespace;
    }
    set namespace(value) {
        this._namespace = value;
    }
    /**
     * Array of type arguments, of a generic type, or a tuple type.
     *
     * Example: A type Dictionary<string,number> would have type arguments [string, number].
     *
     * @type {Type[]}
     * @memberOf PrimaryType
     */
    get typeArguments() {
        return this._typeArguments;
    }
    set typeArguments(value) {
        this._typeArguments = value;
    }
    /**
     * Creates an instance of PrimaryType.
     * @param {string} text Full text for the primary type
     * @param {PrimaryTypeKind} kind Kind of primary type
     *
     * @memberOf PrimaryType
     */
    constructor(text, kind) {
        super(text);
        this._kind = kind;
        this._namespace = null;
        this._typeArguments = [];
    }
}
exports.PrimaryType = PrimaryType;
